@@ -8,10 +8,8 @@
 //! For examples, see the `examples` directory in the source tree.
 #![warn(missing_docs)]
 
-#[macro_use]
-extern crate log;
-extern crate chrono;
 extern crate base64;
+extern crate chrono;
 extern crate reqwest;
 extern crate serde_json;
 
@@ -36,7 +34,7 @@ pub use tournament::{
     TournamentState, TournamentType,
 };
 
-const API_BASE: &'static str = "https://api.challonge.com/v1";
+const API_BASE: &str = "https://api.challonge.com/v1";
 
 fn make_headers(user_name: String, api_key: String) -> reqwest::header::HeaderMap {
     // use headers::Authorization;
