@@ -4,7 +4,6 @@ extern crate serde_json;
 
 use chrono::*;
 use serde_json::Value;
-use std::collections::BTreeMap;
 use std::fmt;
 use std::str::FromStr;
 
@@ -176,7 +175,10 @@ pub struct Player {
 }
 impl Player {
     /// Decodes `Player` from JSON
-    pub fn decode(mut map: &mut BTreeMap<String, Value>, prefix: &str) -> Result<Player, Error> {
+    pub fn decode(
+        mut map: &mut serde_json::Map<String, Value>,
+        prefix: &str,
+    ) -> Result<Player, Error> {
         Ok(Player {
             id: ParticipantId(
                 remove(&mut map, &format!("{}id", prefix))?
@@ -184,7 +186,7 @@ impl Player {
                     .unwrap_or(0),
             ),
             is_prereq_match_loser: remove(&mut map, &format!("{}is_prereq_match_loser", prefix))?
-                .as_boolean()
+                .as_bool()
                 .unwrap_or(false),
             prereq_match_id: remove(&mut map, &format!("{}prereq_match_id", prefix))?
                 .as_u64()
@@ -253,7 +255,7 @@ impl Match {
         let mut tv = into_map(t)?;
 
         let mut started_at = None;
-        if let Some(sa_str) = remove(&mut tv, "started_at")?.as_string() {
+        if let Some(sa_str) = remove(&mut tv, "started_at")?.as_str() {
             if let Ok(sa) = DateTime::parse_from_rfc3339(sa_str) {
                 started_at = Some(sa);
             }
@@ -261,41 +263,37 @@ impl Match {
 
         Ok(Match {
             created_at: DateTime::parse_from_rfc3339(
-                remove(&mut tv, "created_at")?.as_string().unwrap_or(""),
+                remove(&mut tv, "created_at")?.as_str().unwrap_or(""),
             )
             .unwrap(),
             has_attachment: remove(&mut tv, "has_attachment")?
-                .as_boolean()
+                .as_bool()
                 .unwrap_or(false),
             id: MatchId(remove(&mut tv, "id")?.as_u64().unwrap()),
             identifier: remove(&mut tv, "identifier")?
-                .as_string()
+                .as_str()
                 .unwrap_or("")
                 .to_owned(),
-            loser_id: remove(&mut tv, "loser_id")?
-                .as_u64()
-                .map(ParticipantId),
+            loser_id: remove(&mut tv, "loser_id")?.as_u64().map(ParticipantId),
             player1: Player::decode(&mut tv, "player1_").unwrap(),
             player2: Player::decode(&mut tv, "player2_").unwrap(),
             round: remove(&mut tv, "round")?.as_u64().unwrap(),
             started_at,
-            state: MatchState::from_str(remove(&mut tv, "state")?.as_string().unwrap_or(""))
+            state: MatchState::from_str(remove(&mut tv, "state")?.as_str().unwrap_or(""))
                 .unwrap_or(MatchState::All),
             tournament_id: TournamentId::Id(remove(&mut tv, "tournament_id")?.as_u64().unwrap()),
             updated_at: DateTime::parse_from_rfc3339(
-                remove(&mut tv, "updated_at")?.as_string().unwrap_or(""),
+                remove(&mut tv, "updated_at")?.as_str().unwrap_or(""),
             )
             .unwrap(),
-            winner_id: remove(&mut tv, "winner_id")?
-                .as_u64()
-                .map(ParticipantId),
+            winner_id: remove(&mut tv, "winner_id")?.as_u64().map(ParticipantId),
             prerequisite_match_ids_csv: remove(&mut tv, "prerequisite_match_ids_csv")?
-                .as_string()
+                .as_str()
                 .unwrap_or("")
                 .to_owned(),
             scores_csv: MatchScores::decode(
                 remove(&mut tv, "scores_csv")?
-                    .as_string()
+                    .as_str()
                     .unwrap_or("")
                     .to_owned(),
             ),
@@ -321,14 +319,14 @@ mod tests {
             MatchScore(9, 0),
             MatchScore(0, 118),
         ];
-        let mut iter = strings.iter().zip(correct_scores.iter());
-        while let Some(pair) = iter.next() {
+        let iter = strings.iter().zip(correct_scores.iter());
+        for pair in iter {
             if let Ok(ms) = MatchScore::decode(pair.0) {
                 assert_eq!(ms.0, (pair.1).0);
                 assert_eq!(ms.1, (pair.1).1);
                 assert_eq!(ms.to_string(), (pair.1).to_string());
             } else {
-                assert!(false);
+                unreachable!();
             }
         }
     }
@@ -372,15 +370,15 @@ mod tests {
             // assert_eq!(m.attachment_count, );
             // assert_eq!(m.created_at, );
             // assert_eq!(m.group_id, );
-            assert_eq!(m.has_attachment, false);
+            assert!(!m.has_attachment);
             assert_eq!(m.id.0, 23575258);
             assert_eq!(m.identifier, "A");
             assert_eq!(m.loser_id, None);
             assert_eq!(m.player1.id.0, 16543993);
-            assert_eq!(m.player1.is_prereq_match_loser, false);
+            assert!(!m.player1.is_prereq_match_loser);
             assert_eq!(m.player1.prereq_match_id, None);
             assert_eq!(m.player1.votes, 0);
-            assert_eq!(m.player2.is_prereq_match_loser, false);
+            assert!(!m.player2.is_prereq_match_loser);
             assert_eq!(m.player2.prereq_match_id, None);
             assert_eq!(m.player2.id.0, 16543997);
             assert_eq!(m.player2.votes, 3);
@@ -394,14 +392,14 @@ mod tests {
             {
                 let correct_scores = vec![MatchScore(3, 1), MatchScore(3, 2)];
                 assert_eq!(m.scores_csv.0.len(), 2);
-                let mut iter = m.scores_csv.0.iter().zip(correct_scores.iter());
-                while let Some(pair) = iter.next() {
+                let iter = m.scores_csv.0.iter().zip(correct_scores.iter());
+                for pair in iter {
                     assert_eq!((pair.0).0, (pair.1).0);
-                    assert_eq!((pair.1).1, (pair.1).1);
+                    assert_eq!((pair.0).1, (pair.1).1);
                 }
             }
         } else {
-            assert!(false);
+            unreachable!();
         }
     }
 }
