@@ -1,6 +1,5 @@
 use error::Error;
 use serde_json::Value;
-use std::collections::BTreeMap;
 
 pub fn decode_array<T, F: Fn(Value) -> Result<T, Error>>(
     value: Value,
@@ -12,14 +11,14 @@ pub fn decode_array<T, F: Fn(Value) -> Result<T, Error>>(
     }
 }
 
-pub fn into_map(value: Value) -> Result<BTreeMap<String, Value>, Error> {
+pub fn into_map(value: Value) -> Result<serde_json::Map<String, Value>, Error> {
     match value {
         Value::Object(m) => Ok(m),
         value => Err(Error::Decode("Expected object", value)),
     }
 }
 
-pub fn remove(map: &mut BTreeMap<String, Value>, key: &str) -> Result<Value, Error> {
+pub fn remove(map: &mut serde_json::Map<String, Value>, key: &str) -> Result<Value, Error> {
     map.remove(key)
         .ok_or_else(|| Error::Decode("Unexpected absent key", Value::String(key.into())))
 }
